##  Introduction
SAP LeanIX Technology Risk and Compliance allows you to automatically discover and build the inventory of self-built software components such as microservices and tech stacks. It systematically pulls in data from engineering sources through the API and allows you to ingest SBOMs and developer libraries already in use to build the inventory.
  * Microservice discovery: SAP LeanIX Technology Risk and Compliance allows you to automatically discover microservices by relying on community best practices. You can set up automated microservice discovery using a YAML manifest file stored in your Git repository, following the configuration-as-code approach. This allows developers to seamlessly contribute to the technology inventory in SAP LeanIX without having to leave their development context.
As developers update the manifest file to reflect changes in the microservices metadata, SAP LeanIX automatically detects these changes and updates the inventory accordingly. This ensures that the organization has an up-to-date inventory of all self-built software. Discovered microservices are automatically added to the inventory as fact sheets and updated as needed. To learn more, see [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD "Set up microservice discovery using a manifest file in your repository. This method, known as configuration-as-code, enables you to automatically discover microservices and update corresponding fact sheets in SAP LeanIX.").
  * Software bill of material ingestion: With the [Self-Built Software Discovery API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html"), SAP LeanIX allows you to ingest SBOMs from various points in your Software Development Lifecycle (SLDC), such as container registries, CI/CD pipelines, security tooling, and SCM tools like GitLab, Bitbucket, GitHub, and more. The API allows you to easily tie into your build processes where you produce the SBOM and automatically ingest SBOM data generated during the build process of your self-built software, ensuring a near real-time view of your software composition. For more information, see [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.").
  * Tech stack discovery from SBOM: SAP LeanIX Technology Risk and Compliance uses a curated reference catalog to match detailed SBOM components with tech stack frameworks. If a library matches a tech stack, an IT component is generated and linked to a relevant microservice. Libraries are aggregated when many libraries match a single tech stack. Currently, the tech stack discovery supports the discovery of frameworks and databases. The automatic and continuous detection and cataloging of tech stacks helps you streamline your organization's technology stack. The tech radar report aids this effort by providing a comprehensive visual representation of your technology landscape. To learn more, see [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.") and [Radar Report](https://help.sap.com/docs/leanix/ea/radar-report?locale=en-US&state=PRODUCTION&version=CLOUD "A Radar report offers a visual representation of fact sheets categorized in rings and sectors. It aids in understanding an organization's tech landscape and evaluate technology standards.").
